@@ -28,6 +28,8 @@
 
 int main(int argc, char** argv)
 {
+    // Fixes blurry icons with fractional scaling
+    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     QApplication app(argc, argv);
     KLocalizedString::setApplicationDomain("knavalbattle");
 
