@@ -61,47 +61,47 @@ void MainWindow::setupActions()
     QAction* action;
     action = new QAction(i18n("&Single Player"), this);
     action->setIcon(QIcon::fromTheme( QLatin1String( SimpleMenu::iconLocal)));
-    actionCollection()->addAction(QLatin1Literal("game_local"), action);
+    actionCollection()->addAction(QStringLiteral("game_local"), action);
     connect(action, &QAction::triggered, m_main, &PlayField::localGame);
     action = new QAction(i18n("&Host Game..."), this);
     action->setIcon(QIcon::fromTheme( QLatin1String( SimpleMenu::iconServer)));
-    actionCollection()->addAction(QLatin1Literal("game_create_server"), action);
+    actionCollection()->addAction(QStringLiteral("game_create_server"), action);
     connect(action, &QAction::triggered, m_main, &PlayField::createServer);
     action = new QAction(i18n("&Connect to Game..."), this);
     action->setIcon(QIcon::fromTheme( QLatin1String( SimpleMenu::iconClient))),
-    actionCollection()->addAction(QLatin1Literal("game_create_client"), action);
+    actionCollection()->addAction(QStringLiteral("game_create_client"), action);
     connect(action, &QAction::triggered, m_main, &PlayField::createClient);
     // settings
     action = new QAction(i18n("Change &Nickname..."), this);
-    actionCollection()->addAction(QLatin1Literal("options_nickname"), action);
+    actionCollection()->addAction(QStringLiteral("options_nickname"), action);
     connect(action, &QAction::triggered, m_main, &PlayField::changeNick);
     action = new KToggleAction(i18n("&Play Sounds"), this);
     action->setChecked(Settings::enableSounds());
-    actionCollection()->addAction(QLatin1Literal("options_sounds"), action);
+    actionCollection()->addAction(QStringLiteral("options_sounds"), action);
     connect(action, &QAction::triggered, m_main, &PlayField::toggleSounds);
     // This action will be disabled when a game is being run
     action = new KToggleAction(i18n("&Adjacent Ships"), this);
     action->setChecked(Settings::adjacentShips());
-    actionCollection()->addAction(QLatin1Literal("options_adjacent"), action);
+    actionCollection()->addAction(QStringLiteral("options_adjacent"), action);
     connect(action, &QAction::triggered, m_main, &PlayField::toggleAdjacent);
     // This action will be disabled when a game is being run
     action = new KToggleAction(i18n("&Multiple Ships"), this);
     action->setChecked(Settings::severalShips());
-    actionCollection()->addAction(QLatin1Literal("options_multiple_ships"), action);
+    actionCollection()->addAction(QStringLiteral("options_multiple_ships"), action);
     connect(action, &QAction::triggered, m_main, &PlayField::toggleMultiple);
     // config end of game message
     action = new KToggleAction(i18n("Show End-of-Game Message"), this);
     action->setChecked(true);
-    actionCollection()->addAction(QLatin1Literal("options_show_endgame_message"), action);
+    actionCollection()->addAction(QStringLiteral("options_show_endgame_message"), action);
     connect(action, &QAction::triggered, m_main, &PlayField::toggleEndOfGameMessage);
     // actions for grid
     action = new KToggleAction(i18n("Show &Left Grid"), this);
     action->setChecked(true);
-    actionCollection()->addAction(QLatin1Literal("options_showleftgrid"), action);
+    actionCollection()->addAction(QStringLiteral("options_showleftgrid"), action);
     connect(action, &QAction::triggered, m_main, &PlayField::toggleLeftGrid);
     action = new KToggleAction(i18n("Show &Right Grid"), this);
     action->setChecked(true);
-    actionCollection()->addAction(QLatin1Literal("options_showrightgrid"), action);
+    actionCollection()->addAction(QStringLiteral("options_showrightgrid"), action);
     connect(action, &QAction::triggered, m_main, &PlayField::toggleRightGrid);
     
     setupGUI();
@@ -109,12 +109,12 @@ void MainWindow::setupActions()
 
 void MainWindow::startingGame()
 {
-    stateChanged(QLatin1Literal("playing"));
+    stateChanged(QStringLiteral("playing"));
 }
 
 void MainWindow::welcomeScreen()
 {
-    stateChanged(QLatin1Literal("playing"), KXMLGUIClient::StateReverse);
+    stateChanged(QStringLiteral("playing"), KXMLGUIClient::StateReverse);
 }
 
 void MainWindow::closeEvent(QCloseEvent *)
