@@ -163,7 +163,7 @@ void Protocol::readMore()
 #define DEF_COORD(var, varx, vary) DEF_ELEMENT(varx); DEF_ELEMENT(vary); Coord var(varx.toInt(), vary.toInt());
 MessagePtr Protocol::parseMessage(const QString& xmlMessage)
 {
-    qDebug() << "received:" << xmlMessage;
+    qCDebug(KNAVALBATTLE_LOG) << "received:" << xmlMessage;
 
     QDomDocument doc;
     doc.setContent(xmlMessage);
@@ -317,9 +317,10 @@ void Protocol::sendNext()
         m_message_queue.dequeue()->accept(sender);
         
         QTextStream stream(m_device);
-        stream << sender.document().toString() << endl;
+        stream << sender.document().toString() << QLatin1Char('\n');
+        stream.flush();
         
-        qDebug() << "sending:" << sender.document().toString();
+        qCDebug(KNAVALBATTLE_LOG) << "sending:" << sender.document().toString();
     }
 }
 
